@@ -1,10 +1,11 @@
 from rest_framework import serializers
 
 
-class HelloSerializer(serializers.Serializer):
+class DeviceSerializer(serializers.Serializer):
     """
     The serializer of the "Hello" end point
     """
-    push_token = serializers.CharField(required=False)
+    push_token = serializers.CharField(required=True)
     device_type = serializers.CharField(required=False)
+    device_model = serializers.CharField(required=False, default="")
     locale = serializers.CharField(required=False)
